@@ -11,6 +11,7 @@ class Out
 //    char const *d_verbEndl = "\n";          // \n immediately after verb
     bool d_verbEndl = true;                 // \n after verb( and before its
                                             // closing )
+    bool d_verb = true;
 
     char const *d_nl = "\n";                // nl is postponed till the next
 
@@ -26,6 +27,7 @@ class Out
         Out();
         ~Out();                         // writes ) if lines were written
 
+        void noVerb();                  // no verb( ... )
         void noVerbEndl();              // no \n after verb
         void numberLines();             // show line numbers
 
@@ -65,6 +67,11 @@ inline void Out::vindent(size_t count, int ch)
     indent(d_vindent, count, ch);
 }
 
+inline void Out::noVerb()
+{
+    d_verb = false;
+}
+
 inline void Out::noVerbEndl()
 {
     d_verbEndl = false;
