@@ -21,6 +21,7 @@ class Process: private LineType
                                             // configure Process:
         void all();                         //  -A
         void indent(size_t count, int ch);  // line indentation
+        void noVerb();                      // do not use verb(...)
         void noVerbEndl();                  // no \n after verb
         void numberLines();                 // lines are numbered
         void setTarget(char const *target); // specify the target marker
@@ -40,6 +41,11 @@ inline void Process::all()
     d_run = &Process::processAll;
 }
 
+inline void Process::noVerb()
+{
+    d_out.noVerb();
+}
+
 inline void Process::noVerbEndl()
 {
     d_out.noVerbEndl();
