@@ -26,7 +26,7 @@ void Process::processAll()
                     nEmpty = 0;
                 }
                 d_out.insert(d_line.line());
-            [[fallthrough]]
+            [[fallthrough]];
 
             default:
             break;
